@@ -36,7 +36,7 @@ require_once 'model/DateConvert.php';
 require_once 'model/Filter.php';
 require_once 'model/AppState.php';
 
-$authscript  = $App->getConfig('EXTERNAL_AUTH','/usr/lib/benno-web/benno_sqliteauth');
+$authscript  = $App->getConfig('EXTERNAL_AUTH','/usr/lib/benno-web/benno_dbauth');
 
 $login = $App->getParam('login');
 
@@ -94,7 +94,7 @@ $Backend = new Backend($rest_data['URL'],$rest_data['USER'],$rest_data['PASS'],
                        $filterString);
 
 // defaults for extended search form
-$timerange = $App->getConfig('DEFAULT_TIMERANGE');
+$timerange = $App->getConfig('DEFAULT_TIMERANGE','30');
 $ExtQuery = new Query('empty');
 $App->setSession('ExtQuery',$ExtQuery);
 
